@@ -4,7 +4,7 @@ describe 'senlin::policy' do
   shared_examples_for 'senlin-policies' do
     let :params do
       {
-        :policy_path => '/etc/senlin/policy.json',
+        :policy_path => '/etc/senlin/policy.yaml',
         :policies    => {
           'context_is_admin' => {
             'key'   => 'context_is_admin',
@@ -21,6 +21,9 @@ describe 'senlin::policy' do
         :file_user  => 'root',
         :file_group => 'senlin',
       })
+      is_expected.to contain_oslo__policy('senlin_config').with(
+        :policy_file => '/etc/senlin/policy.yaml',
+      )
     end
   end
 
